"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rxjs_1 = require("rxjs");
const operators_1 = require("rxjs/operators");
function streamToRx(stream, pauser) {
    return new rxjs_1.Observable(subscriber => {
        const endHandler = () => subscriber.complete();
        const errorHandler = (e) => subscriber.error(e);
        const dataHandler = (data) => subscriber.next(data);
        let pauseSubscription;
        stream.addListener('end', endHandler);
        stream.addListener('close', endHandler);
        stream.addListener('error', errorHandler);
        stream.addListener('data', dataHandler);
        if (pauser) {
            pauseSubscription = pauser.pipe(operators_1.distinctUntilChanged()).subscribe(function (b) {
                if (b === false) {
                    stream.resume();
                }
                else if (b === true) {
                    stream.pause();
                }
            });
        }
        return () => {
            stream.removeListener('end', endHandler);
            stream.removeListener('close', endHandler);
            stream.removeListener('error', errorHandler);
            stream.removeListener('data', dataHandler);
            if (pauser) {
                pauseSubscription.unsubscribe();
            }
        };
    });
}
exports.streamToRx = streamToRx;
function streamToStringRx(stream, encoding = 'utf8', pauser) {
    return streamToRx(stream, pauser)
        .pipe(operators_1.map(buffer => buffer.toString(encoding)));
}
exports.streamToStringRx = streamToStringRx;
//# sourceMappingURL=streamToRx.js.map